@@ -5,7 +5,7 @@ use strict;
 use Exporter 'import';
 use Carp;
 
-our $VERSION = '0.001002';  # rrr.mmmsss : rrr is major revision; mmm is minor revision; sss is sub-revision; optionally use _sss instead, for alpha sub-releases
+our $VERSION = '0.002';  # rrr.mmmsss : rrr is major revision; mmm is minor revision; sss is sub-revision; optionally use _sss instead, for alpha sub-releases
 
 use Win32::Mechanize::NotepadPlusPlus::Notepad ':vars';
 use Win32::Mechanize::NotepadPlusPlus::Editor ':vars';
@@ -32,7 +32,7 @@ PythonScript plugin.
 
 our @EXPORT = ();   # by default, export nothing
 our @EXPORT_MAIN = qw/notepad editor editor1 editor2/;
-our @EXPORT_VARS = qw/%nppm %nppidm %scimsg/;
+our @EXPORT_VARS = (@Win32::Mechanize::NotepadPlusPlus::Notepad::EXPORT_VARS, @Win32::Mechanize::NotepadPlusPlus::Editor::EXPORT_VARS);
 our @EXPORT_OTHER = qw//;   # maybe eventually, functions to create and destroy additional NPP instances
 our @EXPORT_OK = (@EXPORT_MAIN, @EXPORT_VARS, @EXPORT_OTHER);
 our %EXPORT_TAGS = (
@@ -117,6 +117,27 @@ The Console was a PythonScript feature, beacuse it had an embedded Python interp
 Since Win32::Mechanize::NotepadPlusPlus is an outside-in framework, there is no Perl
 interpreter embedded in Notepad++.
 
+=head1 EXPORTS
+
+By default, the module exports nothing.
+
+=over
+
+=item :main
+
+Exports the L</notepad>, L</editor>, L</editor1>, and L</editor2> functions.
+
+=item :vars
+
+Exports the variables from both L<Win32::Mechanize::NotepadPlusPlus::Notepad::Messages> and
+L<Win32::Mechanize::NotepadPlusPlus::Editor::Messages>
+
+    use Win32::Mechanize::NotepadPlusPlus qw/:vars/;
+    # from Notepad::Messages: %NPPMSG, %VIEW, %MODELESS, %STATUSBAR, %MENUHANDLE, %INTERNALVAR, %LANGTYPE, %WINVER, %WINPLATFORM, %NOTIFICATION, %DOCSTATUS, %NPPIDM, %ENCODINGKEY
+    # from Editor::Messages: %SCIMSG, %SCINTILLANOTIFICATION, and more than 50 others.
+
+=back
+
 =head1 LIMITATIONS
 
 This is the first public release of the module.  In general, it works.  As with all first releases,
@@ -180,4 +201,4 @@ See L<http://dev.perl.org/licenses/> for more information.
 
 =cut
 
-1;
\ No newline at end of file
+1;
