@@ -10,8 +10,7 @@ use POSIX ":sys_wait_h";
 
 use Path::Tiny 0.058 qw/path tempfile/; # 0.018 needed for rootdir and cwd; 0.058 needed for sibling
 
-use Win32::Mechanize::NotepadPlusPlus qw/:main/;  # for %scimsg
-use Win32::Mechanize::NotepadPlusPlus::__sci_msgs;  # for %scimsg
+use Win32::Mechanize::NotepadPlusPlus qw/:main :vars/;  # for %SCIMSG
 
 =head1 NAME
 
@@ -74,7 +73,7 @@ my $_savePID;
 BEGIN { $_savePID = $$; }
 END   { sleep($_END_DELAY) if $_savePID and $$ != $_savePID; }
 
-our @EXPORT_OK = qw/runCodeAndClickPopup saveUserSession restoreUserSession wrapGetLongPathName/;
+our @EXPORT_OK = qw/runCodeAndClickPopup saveUserSession restoreUserSession wrapGetLongPathName dumper/;
 our @EXPORT = qw/runCodeAndClickPopup/;
 our %EXPORT_TAGS = (
     userSession => [qw/saveUserSession restoreUserSession/],
@@ -187,10 +186,11 @@ sub saveUserSession {
     my ($saveUserFileList, $saveUserSession);
     my $unsaved = 0;
     for my $view (0, 1) {
-        my $nb = notepad()->getNumberOpenFiles($view);
+        my $nbView = ($VIEW{PRIMARY_VIEW}, $VIEW{SECOND_VIEW})[$view];
+        my $nb = notepad()->getNumberOpenFiles($nbView);
         for my $idoc ( 0 .. $nb-1 ) {
             notepad()->activateIndex($view,$idoc);
-            $unsaved++ if editor()->{_hwobj}->SendMessage( $scimsg{SCI_GETMODIFY} );
+            $unsaved++ if editor()->{_hwobj}->SendMessage( $SCIMSG{SCI_GETMODIFY} );
             push @$saveUserFileList, notepad()->getCurrentFilename();
         }
     }
@@ -227,7 +227,6 @@ sub saveUserSession {
     };
 
     note "saveUserSession: ", $saveUserSession->canonpath(); # don't want to delete the session
-
     return { session => $saveUserSession, list => $saveUserFileList };
 
 }
@@ -302,5 +301,24 @@ sub wrapGetLongPathName {
     return $lpszLongPath;
 }
 
+=over
 
-1;
\ No newline at end of file
+=item   dumper()
+
+    diag dumper($var1, $var2);
+
+Will look for any characters not in the range C<[\x20-\x7e]> and replace them with a hex notation:
+
+    diag dumper("\n\0");      # prints \x{0A}\x{00}
+
+=back
+
+=cut
+
+sub dumper(@) {
+    my @args = @_;
+    map { $_='<undef>' unless defined $_; s/([^\x20-\x7e])/sprintf'\\x{%02X}',ord($1)/ge; $_ } @args;
+}
+
+
+1;
